@@ -124,6 +124,12 @@ class ConvenientSelenium(NewStyleSelenium):
     super(ConvenientSelenium, self).drag_and_drop(self.resolve_locator(locator),
                                                   movements_string)
 
+  def fire_event(self, locator, event_name, wait = False):
+    self._wait_if_asked(locator, wait)
+    super(ConvenientSelenium, self).fire_event(self.resolve_locator(locator),
+                                               event_name)
+
+
   def select(self, select_locator, 
              value = None, label = None, id = None, index = None, 
              wait = False):
